<?php
/**
 * 	Table of Contents
 *
 *	- nice_pagenavi()
 *	- nice_post_meta()
 *	- nice_post_author()
 *	- nice_display_feedback_items()
 *  - nice_custom_post_types()
 *  - nice_cpt_add_meta_boxes()
 *  - nice_cpt_post_thumbnail_html()
 *  - nice_cpt_title()
 *  - nice_cpt_custom_columns()
 *
 */

/**
 * nice_pagenavi()
 *
 * If wp_pagenavi exists, it shows it.
 * else, it shows the < previous | next > links.
 *
 * @since 1.0.0
 *
 */

if ( ! function_exists( 'nice_pagenavi' ) ) {

	function nice_pagenavi() {

		if ( function_exists( 'wp_pagenavi' ) ) {

			wp_pagenavi();

		} else { ?>

			<?php if ( get_next_posts_link() || get_previous_posts_link() ) { ?>

				<div class="nav-entries col-full">
					<?php next_posts_link( '<div class="nav-prev fl">&laquo; '. __( 'Older posts', 'nicethemes' ) . '</div>' ); ?>
					<?php previous_posts_link( '<div class="nav-next fr">'. __( 'Newer posts', 'nicethemes' ) . ' &raquo;</div>' ); ?>
					<div class="fix"></div>
				</div>

			<?php } ?>

		<?php }
	}
}


/**
 * nice_post_meta()
 *
 * Post metadata, nicely displayed.
 *
 * @since 1.0.0
 *
 */

if ( ! function_exists( 'nice_post_meta' ) ) {

	function nice_post_meta() {
?>
		<p class="post-meta">
							<span class="post-date"><?php the_time( get_option( 'date_format' ) ); ?></span>
							<span class="post-author"><span class="small"><?php _e( 'by', 'nicethemes' ) ?></span> <?php the_author_posts_link(); ?></span>
							<span class="post-category"><span class="small"><?php _e( 'in', 'nicethemes' ) ?></span>
							<?php if ( is_tax( 'portfolio-category' ) ) echo get_the_term_list( get_the_ID(), 'portfolio-category', '', ', ', '' . "\n" );
								else the_category(', ') ?></span>
							<?php edit_post_link( __( '[Edit]', 'nicethemes' ), '<span class="small">', '</span>' ); ?>
		</p>
<?php
	}
}

/**
 * nice_post_author()
 *
 * Post author info, nicely displayed.
 *
 * @since 1.0.0
 *
 */

if ( ! function_exists( 'nice_post_author' ) ) {

	function nice_post_author() {
		global $post, $nice_options;

		if ( isset( $nice_options["nice_post_author"] ) && $nice_options["nice_post_author"] == "true" ) {
?>

			<div id="post-author">
				<div class="profile-image">
					<a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ) ); ?>"><?php echo get_avatar( get_the_author_meta( 'ID' ), '70' ); ?></a>
				</div>
					<div class="profile-content">
						<h3 class="title"><?php printf( esc_attr__( 'About %s', 'nicethemes' ), get_the_author() ); ?></h3>
						<?php the_author_meta( 'description' ); ?>
						<div class="profile-link">
							<a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ) ); ?>">
								<?php printf( __( 'View all posts by %s <span class="meta-nav">&rarr;</span>', 'nicethemes' ), get_the_author() ); ?>
							</a>
						</div><!-- #profile-link	-->
				</div><!-- .post-entries -->
				<div class="fix"></div>
			</div><!-- #post-author -->
<?php
		}
	}
}

/**
 * nice_display_feedback_items()
 *
 * Retrieve feedback items, display them according to settings
 * in @param $args.
 *
 * @since 1.0.0
 *
 *
 * @param array $args Optional. Display info
 * @return string, if $args['echo'] is false.
 */

 if ( ! function_exists( 'nice_display_feedback_items' ) ) {

	function nice_display_feedback_items ( $args = '' ) {

		$defaults = array(
			'post_type'		 => 'feedback',
			'no_found_rows'	 => true,
			'numberposts'	 => 5,
			'orderby'		 => 'rand',
			'order'			 => 'DESC',
			'id'			 => 0,
			'display_author' => true,
			'display_url'	 => true,
			'effect'		 => 'fade', // Options: 'fade', 'none', 'slide'
			'pagination'	 => false,
			'echo'			 => true
		);

		$args = wp_parse_args( $args, $defaults );

		$output = '';

		$items = get_posts( $args );

		// display items
		if ( ! is_wp_error( $items ) && is_array( $items ) && count( $items ) > 0 )  {

			$effect = '';

			if ( $args['effect'] != 'none' ) $effect = ' ' . $args['effect'];

			$output .= '<div class="feedback' . $effect . '">' . "\n";
			$output .= '<div class="feedback-list">' . "\n";

			foreach ( $items as $post ) {

				setup_postdata( $post );

				$feedback_author = '';

				// If we need to display either the author, URL or both, get the data.
				if ( $args['display_author'] == true || $args['display_url'] == true ) {
					$meta = get_post_custom( $post->ID );

					if ( isset( $meta['feedback_author'] ) && ( $meta['feedback_author'][0] != '' ) && $args['display_author'] == true ) {
						$feedback_author .= '<cite class="feedback-author">' . $meta['feedback_author'][0] . '</cite>' . "\n";
					}

					if ( isset( $meta['feedback_url'] ) && ( $meta['feedback_url'][0] != '' ) && $args['display_url'] == true ) {
						$feedback_author .= '<a href="' . $meta['feedback_url'][0] . '" title="' . esc_attr( $meta['feedback_author'][0] ) . '" class="feedback-url">' . $meta['feedback_url'][0] . '</a>';
					}
				}

				$img_class = '';

				$output .= '<div id="quote-' . $post->ID . '" class="quote">' . "\n";

				if ($args['featured_image'] > 0 ) $output .= nice_image( 'echo=0&height='.$args['featured_image'].'&width='.$args['featured_image'].'&class=thumbnail&single=true&id='.$post->ID );
				else $img_class = ' no-img';

					$output .= '<blockquote class="feedback-text' . $img_class . '">' . get_the_content() . '</blockquote>' . "\n";
					$output .= $feedback_author;
				$output .= '</div>' . "\n";

				wp_reset_postdata();
			}

			$output .= '</div>' . "\n";

			if ( $args['pagination'] == true && count( $items ) > 1 && $args['effect'] != 'none' ) {

				$output .= '<div class="pagination">' . "\n";
				$output .= '<a href="#" class="btn-prev">&larr; ' . __( 'Previous', 'nicethemes' ) . '</a>' . "\n";
				$output .= '<a href="#" class="btn-next">' .  __( 'Next', 'nicethemes' ) . ' &rarr;</a>' . "\n";
				$output .= '</div>' . "\n";

			}

			$output .= '</div>' . "\n";
		}

		// Allow child themes/plugins to filter here.

		if ( $args['echo'] != true ) { return $output; }

		// Should only run is "echo" is set to true.
		echo $output;


		wp_reset_query();

	} // end nice_display_feedback_items()
}

function nice_contact_ajax() {

	global $nice_options;

	check_ajax_referer( 'play-nice', 'nonce' );

	if( ! empty( $_POST ) ) {

		$admin_email = get_option( 'nice_email' );

		if ( trim( $admin_email ) == '' )
			$admin_email = get_bloginfo( 'admin_email' );

		$name = $_POST['name'];
		$subject = $_POST['subject'];
		$mail = $_POST['mail'];
		$msg = $_POST['message'];

		$error = "";

		if ( ! $name ) {
			$error .= __( 'Please tell us your name','nicethemes' ) . "<br />";
		}
		if ( ! $mail ) {
			$error .= __( 'Please tell us your E-Mail address','nicethemes' ) . "<br />";
		}
		if ( ! $msg ) {
			$error .= __( 'Please add a message','nicethemes' );
		}

		if ( empty( $error ) ) {

			$mail_subject = '[' . get_bloginfo( 'name' ) . '] ' . __( 'New contact form received','nicethemes' );

			$body = __( 'Name: ', 'nicethemes' ) . "$name \n\n";
			if ( ! empty( $subject ) )
				$body .= __( 'Subject: ', 'nicethemes' ) . "$subject\n\n";

			$body .= __( 'Email: ', 'nicethemes') ."$mail \n\n" . __( 'Comments: ', 'nicethemes' )  ."$msg";

			$headers[] = __( 'From: ', 'nicethemes' ) . $name . ' <' . $mail . '>';
			$headers[] = __( 'Reply-To: ', 'nicethemes' ) . $mail ;
			$headers[] = "X-Mailer: PHP/" . phpversion();

			if ( $sent = wp_mail( $admin_email, $mail_subject, $body, $headers ) ) {
				_e( 'Thank you for leaving a message.', 'nicethemes' );
			} else {
				_e( 'There has been an error, please try again.', 'nicethemes' );
			}

		} else {
			echo $error;
		}
	}
	die();
}

add_action( 'wp_ajax_nopriv_nice_contact_form', 'nice_contact_ajax' );
add_action( 'wp_ajax_nice_contact_form', 'nice_contact_ajax' );


/**
 * nice_custom_post_types()
 *
 * Returns array of custom post types registered for this theme
 *
 * @return (array)
 */

if ( ! function_exists( 'nice_custom_post_types' ) ) :

	function nice_custom_post_types() {
			return array( 'portfolio' );
	}

endif;

/**
 * nice_cpt_add_meta_boxes()
 *
 * Remove the thumbnail metabox and add a new one with the proper Title for the custom post type.
 *
 * @return (string)
 */

if ( ! function_exists( 'nice_cpt_add_meta_boxes' ) ) :

        function nice_cpt_add_meta_boxes() {

                $post_types = nice_custom_post_types();
                foreach ( $post_types as $post_type ) {

					remove_meta_box( 'postimagediv', $post_type, 'side' );
					add_meta_box( 'postimagediv', sprintf( __( '%s Image', 'nicethemes' ), ucwords( $post_type ) ), 'post_thumbnail_meta_box', $post_type, 'side', 'default' );

                }
        }

endif;

add_action( 'add_meta_boxes',  'nice_cpt_add_meta_boxes' );

/**
 * nice_cpt_post_thumbnail_html()
 *
 * Change the default string for the 'Set Featured Image' Link.
 *
 * @return (string) with the new html.
 */

if ( ! function_exists( 'nice_cpt_post_thumbnail_html' ) ) :

        function nice_cpt_post_thumbnail_html( $output ) {

                global $post_type;
                $nice_cpts = nice_custom_post_types();

                // beware of translated admin
                if ( ! empty ( $post_type ) && in_array( $post_type, $nice_cpts ) && ! in_array( $post_type, array( 'service' ) ) ) {
                        $output = str_replace( __( 'Set featured image', 'nicethemes' ), sprintf( __( 'Select / Upload a %s image', 'nicethemes' ), $post_type ), $output );
                        $output = str_replace( __( 'Remove featured image', 'nicethemes' ), sprintf( __( 'Remove %s image', 'nicethemes' ), $post_type ), $output );
                }

                return $output;
        }

endif;

add_filter( 'admin_post_thumbnail_html', 'nice_cpt_post_thumbnail_html' );

/**
 * nice_cpt_title()
 *
 * Change the default string for the Title input.
 *
 * @return (string)
 */

if ( ! function_exists( 'nice_cpt_title' ) ) :

        function nice_cpt_title( $title ){

			$screen = get_current_screen();

			$title = sprintf( __( 'Enter the %s title', 'nicethemes' ), $screen->post_type );

			return $title;
        }

endif;

add_filter( 'enter_title_here', 'nice_cpt_title' );


/**
 * nice_cpt_custom_columns()
 *
 * Adds the thumbnail column for the cutom post type list within the admin section.
 *
 * @return (string)
 */

if ( ! function_exists( 'nice_cpt_custom_columns' ) ) :

        function nice_cpt_custom_columns( $column ) {

			global $post;

			switch ( $column ) {

				case 'thumbnail' :
						if ( has_post_thumbnail( get_the_ID() ) ) { // the current post has a thumbnail
								echo '<a href="' . get_edit_post_link( $post->ID, true ) . '" title="' . esc_attr( __( 'Edit this item', 'nicethemes' ) ) . '">';
								the_post_thumbnail( array( 75, 75 ) );
								echo '</a>';
						}
						else { // the current post lacks a thumbnail

								_e( 'No image', 'nicethemes' );
						}

						// add row_action links for Edit and Trash because there's no title column
						$post_type_object = get_post_type_object( $post->post_type );
						$can_edit_post = current_user_can( $post_type_object->cap->edit_post, $post->ID );
						$always_visible = false; // change to true to make it always show instead of on hover
						$actions = array();

						if ( $can_edit_post && 'trash' != $post->post_status ) {
								$actions['edit'] = '<a href="' . get_edit_post_link( $post->ID, true ) . '" title="' . esc_attr( __( 'Edit this item' ) ) . '">' . __( 'Edit' ) . '</a>';
						}
						if ( current_user_can( $post_type_object->cap->delete_post, $post->ID ) ) {
								if ( 'trash' == $post->post_status )
										$actions['untrash'] = "<a title='" . esc_attr( __( 'Restore this item from the Trash', 'nicethemes' ) ) . "' href='" . wp_nonce_url( admin_url( sprintf( $post_type_object->_edit_link . '&amp;action=untrash', $post->ID ) ), 'untrash-' . $post->post_type . '_' . $post->ID ) . "'>" . __( 'Restore', 'nicethemes' ) . "</a>";
								elseif ( EMPTY_TRASH_DAYS )
										$actions['trash'] = "<a class='submitdelete' title='" . esc_attr( __( 'Move this item to the Trash', 'nicethemes' ) ) . "' href='" . get_delete_post_link( $post->ID ) . "'>" . __( 'Trash', 'nicethemes' ) . "</a>";
								if ( 'trash' == $post->post_status || ! EMPTY_TRASH_DAYS )
										$actions['delete'] = "<a class='submitdelete' title='" . esc_attr( __( 'Delete this item permanently', 'nicethemes' ) ) . "' href='" . get_delete_post_link( $post->ID, '', true ) . "'>" . __( 'Delete Permanently', 'nicethemes' ) . "</a>";
						}

						$action_count = count( $actions );
						$i = 0;
						$out = '<div class="' . ( $always_visible ? 'row-actions-visible' : 'row-actions' ) . '">';
						foreach ( $actions as $action => $link ) {
								++$i;
								( $i == $action_count ) ? $sep = '' : $sep = ' | ';
								$out .= "<span class='$action'>$link$sep</span>";
						}
						$out .= '</div>';

						echo $out;
						break;

				/* If displaying the 'category' column. */
				case 'category' :

						$cat_name = 'category';

						if( ! strcmp( $post->post_type, 'portfolio' ) )
								$cat_name = 'portfolio-category';

						$terms = get_the_terms( get_the_ID(), $cat_name );

						/* If terms were found. */
						if ( ! empty( $terms ) ) {

										$out = array();

										/* Loop through each term, linking to the 'edit posts' page for the specific term. */
										foreach ( $terms as $term ) {
														$out[] = sprintf( '%s',
																		esc_html( sanitize_term_field( 'name', $term->name, $term->term_id, 'genre', 'display' ) )
														);
										}

										/* Join the terms, separating them with a comma. */
										echo join( ', ', $out );
						}

						/* If no terms were found, output a default message. */
						else {
										echo '&mdash;';
						}

						break;

				/* Just break out of the switch statement for everything else. */
				default :
						break;
			}
        }

endif;

add_action( 'manage_posts_custom_column',  'nice_cpt_custom_columns' );