<?php
/**
 * Table of Contents (options.php)
 *
 *	- nice_options_global()
 *	- nice_options()
 *
 */


// make options global.
add_action( 'init', 'nice_options_global' );


function nice_options_global(){
	global $nice_options;
	$nice_options = get_option( 'nice_options' );
}


add_action( 'admin_head', 'nice_options' );

/**
 * nice_options()
 *
 * Define theme options.
 *
 * @since 1.0.0
 *
 */

function nice_options()
{

	$prefix = NICE_PREFIX;

	/*
	* Nice Options
	*/

	$nice_options 	= array ();

	$nice_options[] = array( 'name' 	=> __( 'General Settings', 'nicethemes' ),
							 'type' 	=> 'heading');

	$nice_options[] = array( 'name' 	=> __( 'Custom Logo', 'nicethemes' ),
							 'desc' 	=> __( 'Upload a custom logo or enter the image URL', 'nicethemes' ),
							 'id' 		=> $prefix . '_logo',
							 'std' 		=> '',
							 'type' 	=> 'upload');

	$nice_options[] = array( 'name' 	=> __( 'Intro Message', 'nicethemes' ),
							 'desc' 	=> __( 'Write an intro message for your blog', 'nicethemes' ),
							 'id' 		=> $prefix . '_intro',
							 'std' 		=> __( "Hello, my name is John Doe and I'm a designer + Illustrator currently based in California .", 'nicethemes' ),
							 'type' 	=> 'textarea');

	$nice_options[] = array( 'name' 	=> __( 'Custom Favicon', 'nicethemes' ),
							 'desc' 	=> __( 'Upload a favicon if you want to replace the one by default.', 'nicethemes' ),
							 'id' 		=> $prefix . '_favicon',
							 'std' 		=> '',
							 'type' 	=> 'upload');

	$nice_options[] = array( 'name' 	=> __( 'Contact Form Email Address', 'nicethemes' ),
							 'desc' 	=> __( 'Enter the email address where you\'d like to receive emails from the contact form, or leave blank to use admin email.', 'nicethemes' ),
							 'id' 		=> $prefix . '_email',
							 'std' 		=> '',
							 'tip' 		=> '',
							 'type' 	=> 'text');

	$nice_options[] = array( 'name' 	=> __( 'Post Author Box', 'nicethemes' ),
							 'desc' 	=> __( 'This will enable the post author box on the single posts page. Edit description in Users > Your Profile . ', 'nicethemes' ),
							 'id' 		=> $prefix . '_post_author',
							 'std' 		=> 'true',
							 'tip' 		=> '',
							 'type' 	=> 'checkbox');

	$nice_options[] = array( 'name' 	=> __( 'Tracking Code', 'nicethemes' ),
							 'desc' 	=> __( 'Insert the code if you have one. Google analytics, etc.', 'nicethemes' ),
							 'id' 		=> $prefix . '_tracking_code',
							 'std' 		=> '',
							 'tip' 		=> '',
							 'type' 	=> 'textarea');


	/* Styles */
	$nice_options[] = array( 'name' 	=> __( 'Styles', 'nicethemes' ),
							 'type' 	=> 'heading');


	$nice_options[] = array( 'name' 	=> __( 'Custom CSS', 'nicethemes' ),
							 'desc' 	=> __( 'Quickly add some CSS to your theme by adding it to this block . ', 'nicethemes' ),
							 'id' 		=> $prefix . '_custom_css',
							 'std' 		=> '',
							 'tip' 		=> '',
							 'type' 	=> 'textarea');

	/* Images */

	$nice_options[] = array( 'name' 	=> __( 'Images', 'nicethemes' ),
							 'type' 	=> 'heading' );

	$nice_options[] = array( 'name' 	=> __( 'WP Resize Cropping', 'nicethemes' ),
							 'desc' 	=> __( 'The post thumbnail will be cropped to match the target aspect ratio.', 'nicethemes' ),
							 'id' 		=> $prefix . '_wp_resize_crop',
							 'std' 		=> 'true',
							 'tip' 		=> '',
							 'type' 	=> 'checkbox' );

	$nice_options[] = array( 'name' 	=> __( 'JPEG Quality', 'nicethemes' ),
							 'desc' 	=> __( 'Change the JPEG compression-level of uploaded images and thumbnails.(Default is 90)', 'nicethemes' ),
							 'id' 		=> $prefix . '_jpeg_quality',
							 'std' 		=> array( 'range' => 'min', 'value' => '90', 'min' => '40', 'max' => '100', 'unit' => '%' ),
							 'type' 	=> 'slider' );

	/* Social Media */
	$nice_options[] = array( 'name' 	=> __( 'Social Media', 'nicethemes' ),
							 'type' 	=> 'heading');

	$nice_options[] = array( 'name' 	=> __( 'Facebook URL', 'nicethemes' ),
							 'desc' 	=> __( '', 'nicethemes' ),
							 'id' 		=> $prefix . '_facebook_url',
							 'std' 		=> '',
							 'tip' 		=> '',
							 'type' 	=> 'text');

	$nice_options[] = array( 'name' 	=> __( 'Twitter URL', 'nicethemes' ),
							 'desc' 	=> __( '', 'nicethemes' ),
							 'id' 		=> $prefix . '_twitter_url',
							 'std' 		=> '',
							 'tip' 		=> '',
							 'type' 	=> 'text');

	$nice_options[] = array( 'name' 	=> __( 'Google+ URL', 'nicethemes' ),
							 'desc' 	=> __( '', 'nicethemes' ),
							 'id' 		=> $prefix . '_google_url',
							 'std' 		=> '',
							 'tip' 		=> '',
							 'type' 	=> 'text');

	$nice_options[] = array( 'name' 	=> __( 'Dribbble URL', 'nicethemes' ),
							 'desc' 	=> __( '', 'nicethemes' ),
							 'id' 		=> $prefix . '_dribbble_url',
							 'std' 		=> '',
							 'tip' 		=> '',
							 'type' 	=> 'text');

	$nice_options[] = array( 'name' 	=> __( 'Vimeo URL', 'nicethemes' ),
							 'desc' 	=> __( '', 'nicethemes' ),
							 'id' 		=> $prefix . '_vimeo_url',
							 'std' 		=> '',
							 'tip' 		=> '',
							 'type' 	=> 'text');

	$nice_options[] = array( 'name' 	=> __( 'Forrst URL', 'nicethemes' ),
							 'desc' 	=> __( '', 'nicethemes' ),
							 'id' 		=> $prefix . '_forrst_url',
							 'std' 		=> '',
							 'tip' 		=> '',
							 'type' 	=> 'text');

	$nice_options[] = array( 'name' 	=> __( 'Last.fm URL', 'nicethemes' ),
							 'desc' 	=> __( '', 'nicethemes' ),
							 'id' 		=> $prefix . '_lastfm_url',
							 'std' 		=> '',
							 'tip' 		=> '',
							 'type' 	=> 'text');

	$nice_options[] = array( 'name' 	=> __( 'Tumblr URL', 'nicethemes' ),
							 'desc' 	=> __( '', 'nicethemes' ),
							 'id' 		=> $prefix . '_tumblr_url',
							 'std' 		=> '',
							 'tip' 		=> '',
							 'type' 	=> 'text');

	$nice_options[] = array( 'name' 	=> __( 'Digg URL', 'nicethemes' ),
							 'desc' 	=> __( '', 'nicethemes' ),
							 'id' 		=> $prefix . '_digg_url',
							 'std' 		=> '',
							 'tip' 		=> '',
							 'type' 	=> 'text');

	$nice_options[] = array( 'name' 	=> __( 'Flickr URL', 'nicethemes' ),
							 'desc' 	=> __( '', 'nicethemes' ),
							 'id' 		=> $prefix . '_flickr_url',
							 'std' 		=> '',
							 'tip' 		=> '',
							 'type' 	=> 'text');

	$nice_options[] = array( 'name' 	=> __( 'Youtube URL', 'nicethemes' ),
							 'desc' 	=> __( '', 'nicethemes' ),
							 'id' 		=> $prefix . '_youtube_url',
							 'std' 		=> '',
							 'tip' 		=> '',
							 'type' 	=> 'text');

	$nice_options[] = array( 'name' 	=> __( 'Behance URL', 'nicethemes' ),
							 'desc' 	=> __( '', 'nicethemes' ),
							 'id' 		=> $prefix . '_behance_url',
							 'std' 		=> '',
							 'tip' 		=> '',
							 'type' 	=> 'text');

	$nice_options[] = array( 'name' 	=> __( 'Blogger URL', 'nicethemes' ),
							 'desc' 	=> __( '', 'nicethemes' ),
							 'id' 		=> $prefix . '_blogger_url',
							 'std' 		=> '',
							 'tip' 		=> '',
							 'type' 	=> 'text');

	$nice_options[] = array( 'name' 	=> __( 'Quora URL', 'nicethemes' ),
							 'desc' 	=> __( '', 'nicethemes' ),
							 'id' 		=> $prefix . '_quora_url',
							 'std' 		=> '',
							 'tip' 		=> '',
							 'type' 	=> 'text');

	$nice_options[] = array( 'name' 	=> __( 'Linkedin URL', 'nicethemes' ),
							 'desc' 	=> __( '', 'nicethemes' ),
							 'id' 		=> $prefix . '_linkedin_url',
							 'std' 		=> '',
							 'tip' 		=> '',
							 'type' 	=> 'text');

if ( get_option( 'nice_template' ) != $nice_options ) update_option( 'nice_template', $nice_options );

}


?>