<?php
/**
 * Table of Contents (scripts.php)
 *
 *	- nice_scripts_css()
 *	- nice_scripts_js()
 *	- nice_contact_js()

 *
 */

if ( ! is_admin() ):

	// he's watching the theme, let's load js and css scripts :)
	add_action( 'wp_print_scripts', 'nice_scripts_js' );

endif;


/**
 * nice_scripts_css()
 *
 * register css styles and enqueue them
 *
 * @since 1.0.0
 *
 */
if ( ! function_exists( 'nice_scripts_css' ) ) {

	function nice_scripts_css() {

		wp_register_style( 'nice-style', get_stylesheet_uri() );
		wp_enqueue_style( 'nice-style' );

	}

}

add_action( 'wp_enqueue_scripts', 'nice_scripts_css', 1 );


/**
 * nice_scripts_js()
 *
 * register js scripts and enqueue them
 *
 * @since 1.0.0
 *
 * @uses wp_register_script, wp_enqueue_script
 *
 */

if ( ! function_exists( 'nice_scripts_js' ) ) :

	function nice_scripts_js() {
		global $nice_options;

		wp_register_script( 'slides', get_template_directory_uri() . '/includes/js/slides.min.jquery.js', array( 'jquery' ) );
		wp_register_script( 'nice-custom', get_template_directory_uri() . '/includes/js/general.js', array( 'jquery' ) );
		wp_register_script( 'nice-slides', get_template_directory_uri() . '/includes/js/nice-slides.js', array( 'jquery', 'slides' ) );
		wp_register_script( 'nice-contact-validation', 'http://ajax.microsoft.com/ajax/jquery.validate/1.7/jquery.validate.min.js', array( 'jquery' ) );

		wp_enqueue_script( 'nice-custom' );

		$load_contact_js = false;

		$load_contact_js = apply_filters( 'nice_load_contact_js', $load_contact_js );

		if ( $load_contact_js ) {
			wp_enqueue_script( 'nice-contact-validation' );
			add_action( 'wp_head', 'nice_contact_js', 10 );
		}

		if ( is_singular( 'portfolio' ) ) wp_enqueue_script( 'nice-slides' );

		if ( is_home() ) {
			// do something with scripts for home page.
		}

		do_action( 'nice_scripts_js' );

	} // end nice_scripts_js
endif;


/**
 * nice_contact_js()
 *
 * print js for contact form
 *
 * @since 1.0.0
 *
 */
if ( ! function_exists( 'nice_contact_js' ) ):

	function nice_contact_js() {
		// being here we can set admin-ajax.php for WP multisite
		?>
		<script type="text/javascript">
		//<![CDATA[
		jQuery(document).ready(function($) {

			jQuery('#nice_contact').validate({

				messages: {
						"name":{"required":"<?php _e( 'Please enter your name.', 'nicethemes' ); ?>"},
						"mail":{"required":"<?php _e( 'Please enter your email address.', 'nicethemes' ); ?>"},
						"message":{"required":"<?php _e( 'Please enter a message.', 'nicethemes' ); ?>"}
				},

				submitHandler: function(form) {

					var str = jQuery('#nice_contact').serialize();

					jQuery.ajax({
						type: "POST",
						url: "<?php echo admin_url();?>admin-ajax.php",
						data: 'action=nice_contact_form&nonce=<?php echo wp_create_nonce("play-nice");?>&' + str,
						success: function(msg) {
							jQuery("#node").ajaxComplete(function(event, request, settings){
									if(msg == 'sent') {
										jQuery(".nice-contact-form #node").hide();
										jQuery(".nice-contact-form #success").fadeIn("slow");
										jQuery("#nice_contact input[type=text], #nice_contact textarea").val("");
									}else {
										result = msg;
										jQuery(".nice-contact-form #node").html(result);
										jQuery(".nice-contact-form #node").fadeIn("slow");
									}
							});
						}
					});
					return false;
					form.submit();
				}
			});
		});
		 //]]>
		</script>
		<?php

	}
endif;

?>